@@ -13,11 +13,12 @@ class InstagramOAuth2Adapter(OAuth2Adapter):
     provider_id = InstagramProvider.id
     access_token_url = 'https://api.instagram.com/oauth/access_token'
     authorize_url = 'https://api.instagram.com/oauth/authorize'
-    profile_url = 'https://api.instagram.com/v1/users/self'
+    profile_url = 'https://graph.instagram.com/me'
 
     def complete_login(self, request, app, token, **kwargs):
         resp = requests.get(self.profile_url,
-                            params={'access_token': token.token})
+                            params={'access_token': token.token,
+                                    'fields': ['id', 'username']})
         resp.raise_for_status()
         extra_data = resp.json()
         return self.get_provider().sociallogin_from_response(request,
